# Check node status and report possibly bad nodes
proc checkNodes { } {
    # number of objects in the wrong state
    set badNodes {}

    # iterate through them
    foreach  obj [ Node list] {
        set showStat [ catch { Node show $obj -asInteger} objStat ]
        if { $showStat != 0 } {
            # error
            puts "CHECK:  unabled to show state of node $obj. Check its admin server"
            continue
        }
        set fullName "****Unknown Node Path****"
        set desiredState -1 
        set currentState -1
        foreach attribute $objStat {
            set attrName [ lindex $attribute 0 ]
            if { [ llength $attribute ] > 1 }  {
                set attrVal  [ lindex $attribute 1 ]
            } else {
                set attrVal "****UnknownAttributeValue****"
            }
            switch $attrName {
                FullName  { set fullName $attrVal }
                DesiredState { set desiredState $attrVal }
                CurrentState { set currentState $attrVal }
            }
        }
        if { $currentState !=  $desiredState } {
            set tempcurrentState [getStr $currentState]
            set tempdesiredState [getStr $desiredState]
            set badNodes [concat  $badNodes $obj]
            puts "CHECK: $fullName may have to be restarted: currentState: $tempcurrentState ($currentState), desiredState: $tempdesiredState ($desiredState)"
        } else {
            set tempcurrentState [getStr $currentState]
            set tempdesiredState [getStr $desiredState]
            puts "ok: $fullName, currentState: $tempcurrentState ($currentState), desiredState: $tempdesiredState ($desiredState)"
        }
    }
    return $badNodes
}

# check to see if an app server is in the list of bad nodes.
proc isBadNode { appServer badNodes } {
    set temp1 [ split $appServer / ]
    if { [llength $temp1 ] <= 1 } {
        return 0
    }
    set name  [lindex $temp1 1]
    set name "/$name/"
    if { [lsearch -exact $badNodes $name] >= 0  } {
        return 1
    }
    return 0
}

# isNode: true if reporting Node, otherwise ApplicationServer
# restart: true if server is to be restarted.
proc checkAppServers { badNodes { restart 0 } } {
    set numRestart 0
    # iterate through all app servers
    foreach  obj [ ApplicationServer list] {
        if { [ isBadNode $obj $badNodes ] } { 
            puts "skipping: $obj: its node may be bad"
            continue
        }
        set stat [ catch { ApplicationServer show $obj -asInteger } objStat ]
        if { $stat != 0 } {
            # error
            puts "ERROR: unable to find state of app server $obj"
            continue
        } 
        set fullName "****Unknown ApplicationServer Path****"
        set desiredState -1 
        set currentState -1
        foreach attribute $objStat {
            set attrName [ lindex $attribute 0 ]
            if { [ llength $attribute ] > 1 }  {
                set attrVal  [ lindex $attribute 1 ]
            } else {
                set attrVal "****UnknownAttributeValue****"
            }
            switch $attrName {
                FullName  { set fullName $attrVal }
                DesiredState { set desiredState $attrVal }
                CurrentState { set currentState $attrVal }
            }
        }
        if { $currentState !=  $desiredState } {
            if { ($restart > 0)  && ($desiredState == 3) } {
             set tempcurrentState [getStr $currentState]
             set tempdesiredState [getStr $desiredState]
                puts "RESTARTING: $fullName currentState($tempcurrentState) ($currentState) is not the desiredState($tempdesiredState) ($desiredState)"
                set numRestart [expr $numRestart+1]
                set ret [catch {ApplicationServer start $obj} msg ]
                if { $ret > 0 } {
                    puts "FAILED to restart server. Error message: $msg"
                }
            } else {
             set tempcurrentState [getStr $currentState]
             set tempdesiredState [getStr $desiredState]
                puts "CHECK: $fullName currentState($tempcurrentState) ($currentState) is not the desiredState($tempdesiredState) ($desiredState)"
            }
        } else {
          set tempcurrentState [getStr $currentState]
             set tempdesiredState [getStr $desiredState]
            puts "ok: $fullName currentState($tempcurrentState) ($currentState) is the desiredState:($tempdesiredState) ($desiredState)"
        }
    }
    return $numRestart
}

# This is the main entry point to check nodes and servers.
# Set restart to 1 to automatically restart servers whose desired state
# is Running, but whose current state is not.
proc restartServer  {  {restart 0 } } {
    puts "Checking nodes"
    puts "--------------------------------------------------------"
    set badNodes [checkNodes ]
    set numBadNodes [llength $badNodes]
    puts "--------------------------------------------------------"
    if { $numBadNodes > 0 } {
        puts "There are $numBadNodes nodes that may not be working"
        puts "Please check and restart admin servers on those nodes"
    } else {
        puts "All nodes appear to be OK"
    }
    puts "--------------------------------------------------------"
    if { $restart > 0 } {
        puts "Checking and restarting Servers"
    } else {
        puts "Checking Servers"
    }
    puts "--------------------------------------------------------"
    set serversToRestart [checkAppServers $badNodes $restart]
    puts "--------------------------------------------------------"
    if { $restart > 0 }  {
        puts "Attempted to restart $serversToRestart application servers"
    }  else {
       if { $serversToRestart == 0 } {
           puts "All app servers appear to be OK"
       } else {
            puts "$serversToRestart server(s) may not be working "
       }
    }
}

# To map the attributes with the string
proc getStr { attrnum } {
  switch $attrnum {
    0 { return "UNINITIALIZED"}
    1 { return "INITIALIZING" }
    2 { return "INITIALIZATION_FAILED" }
    3 { return "RUNNING" }
    4 { return "TERMINATING" }
    5 { return "STOPPED" }
    6 { return "LOST_CONTACT" }
   }

}
