@rem PTF/Efix Uninstall Script (AE/AEs)

@if     defined echo echo %echo%
@if not defined echo echo off
setLocal

set ScriptVersion=1.9.1.31
set ScriptUpdate=8/16/02

set REL=was40
set PTFNUM=PTF_5
set PTFDescription=IBM WebSphere Application Server V4.0.5 AE/AEs Fixpack
set PTFNUMSPACED=PTF 5

echo.
echo Uninstall Script
echo %PTFDescription%
echo Please shut down the Application Server, AAT and any WebServers that might be running
echo If not the PTF may not be uninstalled properly.
echo.
echo Script Version: %ScriptVersion%
echo Script Update: %ScriptUpdate%
echo.

:main
    goto parseArguments
    :afterParseArguments
    goto initialize
    :afterInitialize
    goto detectUninstalls
    :afterDetectUninstalls
    goto performUninstalls
    :afterPerformUninstalls
goto complete

:parseArguments
    if "%1" == "-?"         goto usage
    if /I "%1" == "USAGE"   goto usage
    if /I "%1" == "-USAGE"  goto usage
    if /I "%1" == "HELP"    goto help
    if /I "%1" == "-HELP"   goto help

    if /I "%1" == "-SILENT" goto silentTrue
    goto silentDone
    :silentTrue
        set SILENT=true
        echo Enabling silent mode.
    :silentDone
goto afterParseArguments

:help 
    echo Help:
    echo.
    echo uninstall_ptf.bat [options]
    echo.
    echo The uninstall script is assumed to exist in the same directory
    echo as the jar files containing backup information.  The script file
    echo 'LogEvent.sh' must be available in the same directory as the
    echo uninstall script.  The utility program 'GetInput.exe' must
    echo be available in the same directory as well.
    echo.
    echo The directory containing the uninstall script is taken as a base
    echo for searching for the default java home directory and as the base
    echo for searching for the default logs directory.
    echo.
    echo Valid options for the uninstall script include the following:
    echo.
    echo     -usage           [Show this usage information]
    echo     -help            [Show comprehensive help]
    echo.
    echo Both of these two options cause an immediate exit from the uninstall
    echo script.
    echo.
    echo Valid options for the uninstall script also includes:
    echo.
    echo     -silent          [Enable silent mode]
    echo.
    echo Specifying '-silent' causes silent mode to be enabled.  In silent mode
    echo no user interaction is performed.  Default values, as described below,
    echo will be used for required values.
    echo.
    echo The uninstall script respects the following environment variables:
    echo.
    echo Use the 'SILENT' environment variable to specify silent mode:
    echo.
    echo     SILENT           [Specify silent mode]
    echo.
    echo By default, silent mode is disabled.
    echo.
    echo The value of the SILENT variable must be either 'true' or 'false'.
    echo Setting this varible to 'true' has the same effect as using the
    echo '-silent' command line option.
    echo.
    echo Use the 'TMP' environment variable to specify the directory for
    echo temporary files:
    echo.
    echo     TMP              [Temporary Directory]
    echo.
    echo The summary log file, as well as a number of temporary files,
    echo are placed in the temporary directory.
    echo.
    echo If not set the TMP directory defaults to the current directory.
    echo.
    echo Use BACKUP_DIR to specify the location from which the uninstall
    echo script is being run:
    echo.
    echo     BACKUP_DIR       [Backup Directory]
    echo.
    echo The backup directory is used to locate utility programs and
    echo backup jar files, and is the first place checked for java
    echo and for a logs directory.
    echo.
    echo The backup directory defaults to the current directory.
    echo.
    echo (Note that 'BACKUP_DIR' is only available as an option when
    echo running under Windows.)
    echo.
    echo Use LOGS_DIR to specify the location for log files, including
    echo the final location for the summary log file:
    echo.
    echo     LOGS_DIR         [Logs Directory]
    echo.
    echo The logs directory defaults to the directory 'logs' beneath the
    echo backup directory.
    echo.
    echo A summary log, named using the prefix 'Summary_uninstall_%PTFNUM%"',"
    echo plus the starting time of running this script, is generated and
    echo placed in the temporary directory and is finally copied into the
    echo logs directory.
    echo.
    echo Logs for each of the selected uninstall operations are placed in the
    echo logs directory as well.
    echo.
    echo Use 'JAVA_UPDATE_HOME' to specify the java home directory:
    echo.
    echo     JAVA_UPDATE_HOME [Directory containing the JDK]
    echo.
    echo The java home directory must contain the java executable 'jre\bin\java.exe'.
    echo The JDK home directory defaults to 'java' beneath the backup directory.
    echo.
    echo Use the following four options to cause portions of the uninstall
    echo operation to be skipped:
    echo.
    echo     SKIP_RESTORE_WAS [Skip the Application Server restoration]
    echo     SKIP_RESTORE_JDK [Skip the JDK restoration]
    echo     SKIP_RESTORE_IHS [Skip the IBM HTTP Server restoration]
    echo     SKIP_RESTORE_J2C [Skip the J2C Connector restoration]
    echo.
    echo Each of these four environment variables are used to forcably disable a
    echo portion of the restoration.  By default, the uninstall script examines
    echo the backup directory for jar files containing backup information and
    echo performs a restoration using each of the noted backup jar files.
    echo.
    echo Exit code 0
goto egress

:usage 
    echo Usage:
    echo.
    echo uninstall_ptf.sh [options]
    echo.
    echo Valid options are the following:
    echo.
    echo     -usage           [Show this usage information]
    echo     -help            [Show comprehensive help]
    echo     -silent          [Enable silent mode]
    echo.
    echo A number of environment variables are respected:
    echo.
    echo     SILENT           [Specify silent mode]
    echo     TMP              [Temporary Directory]
    echo     BACKUP_DIR       [Directory with Backup Files]
    echo     LOGS_DIR         [Logs Directory]
    echo     JAVA_UPDATE_HOME [Directory containing the JDK]
    echo     SKIP_RESTORE_WAS [Skip the Application Server restoration]
    echo     SKIP_RESTORE_JDK [Skip the JDK restoration]
    echo     SKIP_RESTORE_IHS [Skip the IBM HTTP Server restoration]
    echo     SKIP_RESTORE_J2C [Skip the J2C Connector restoration]
    echo.
    echo Use the -help option to see more comprehensive help.
    echo.
    echo Exit code 0
goto egress

:initialize 
    goto initBasic
    :afterInitBasic
    goto initTmp
    :afterInitTmp
    goto initSummary
    :afterInitSummary
    goto initSilent
    :afterInitSilent
    goto initLogs
    :afterInitLogs
    goto initJava
    :afterInitJava
goto afterInitialize

:initBasic 
    if NOT "%BACKUP_DIR%" == "" goto noBackupDirFalse
    :noBackupDirTrue
        set BACKUP_DIR=.
        echo Setting the backup directory to the current directory.
        echo.
        goto noBackupDirDone
    :noBackupDirFalse
        echo Noted the backup directory as [ %BACKUP_DIR% ].
        echo.
    :noBackupDirDone

    set LOGEVENT_BASE=%BACKUP_DIR%\LogEvent.bat

    if exist "%LOGEVENT_BASE%" goto logEventTrue
    :logEventFalse
        echo Cannot find required log utility file in the backup directory:
        echo %LOGEVENT%
        echo.
        echo Result code: 1
        echo The uninstall of WebSphere %PTFNUMSPACED% did not complete successfully.
        
        goto egress
    :logEventTrue
        set LOGEVENT=call "%LOGEVENT_BASE%"
        set LOGECHO=%LOGEVENT% echo
        set LOGBLANK=%LOGEVENT% BlankLine
    :logEventDone

    set GETINPUT=%BACKUP_DIR%\GetInput.exe

    if exist "%GETINPUT%" goto getInputDone
    :getInputFalse
        echo Cannot find required input utility file in the backup directory:
        echo %GETINPUT%
        echo.
        echo Result code: 1
        echo The uninstall of WebSphere %PTFNUMSPACED% did not complete successfully.
        goto egress
    :getInputDone

    %GETINPUT% SQLTS short "%TMP%\GETTS.BAT" & call "%TMP%\GETTS.BAT" & del "%TMP%\GETTS.BAT"
    set STARTTIME=%SQLTS%
goto afterInitBasic

:initTmp 
    if "%TMP%" == "" goto tmpFalse
    :tmpTrue
        echo Accepting environment specified temporary directory ['TMP']:
        echo %TMP%
        goto tmpDone
    :tmpFalse
        echo Temporary files will be placed in the current directory.
        set TMP=.
    :tmpDone
goto afterInitTmp

:initSummary 
    rem SUMMARYLOG is required by 'LogEvent.bat'

    set SUMMARYBASE=Summary_uninstall_%PTFNUM%_%STARTTIME%.log
    set SUMMARYLOG=%TMP%\%SUMMARYBASE%

    %LOGECHO% %PTFDescription%
    %LOGECHO% Uninstall Program
    %LOGECHO% Script Version: %ScriptVersion%
    %LOGECHO% Script Update: %ScriptUpdate%
    %LOGBLANK%

    %LOGECHO% Writing the initial summary log to:
    %LOGECHO% [ %SUMMARYLOG% ]
    %LOGBLANK%
    %LOGECHO% Start Time: [ %STARTTIME% ]
    %LOGBLANK%
    %LOGECHO% Backup Directory:
    %LOGECHO% [ %BACKUP_DIR%]
    %LOGBLANK%
goto afterInitSummary 

:initSilent 
    if "%SILENT%" == "" goto silentSetFalse
    :silentSetTrue
        if NOT "%SILENT%" == "true" goto silentFalse
        :silentTrue
            %LOGECHO% SILENT mode is enabled.
            %LOGBLANK%
            goto silentDone
        :silentFalse
            %LOGECHO% SILENT mode is disabled.
            %LOGBLANK%
            set SILENT=false
        :silentDone
        goto silentSetDone
    :silentSetFalse
        %LOGECHO% SILENT mode is disabled.
        %LOGBLANK%
        set SILENT=false
    :silentSetDone
goto afterInitSilent 

:initLogs 
    set LEAVELOG=false

    if "%LOGS_DIR%" == "" goto logsSetFalse
    :logsSetTrue
        %LOGECHO% The LOGS directory was noted as [ %LOGS_DIR% ].
        %LOGBLANK%
        echo Testing > "%LOGS_DIR%\ZZXRM.tmp"
        if NOT exist "%LOGS_DIR%\ZZXRM.tmp" goto wroteLogSilentFalse
        :wroteLogSilentTrue
            del "%LOGS_DIR%\ZZXRM.tmp"
            %LOGECHO% Accepting the specified directory as the logs directory.
            %LOGBLANK%
            goto wroteLogSilentDone
        :wroteLogSilentFalse
            %LOGECHO% The specified directory is not writable.
            %LOGBLANK%
            goto quickExit
        :wroteLogSilentDone
        goto logsSetDone

    :logsSetFalse
        if NOT "%SILENT%" == "true" goto logsSilentFalse
        :logsSilentTrue
            if NOT exist "%BACKUP_DIR%\logs" goto logsExistsDone
            :logsExistsTrue
                set LOGS_DIR=%BACKUP_DIR%\logs
                %LOGECHO% A logs directory is present in the backup directory:
                %LOGECHO% [ %LOGS_DIR% ]
                echo Testing > "%LOGS_DIR%\ZZXRM.tmp"
                if NOT exist "%LOGS_DIR%\ZZXRM.tmp" goto wroteLogsFalse
                :wroteLogsTrue
                    del "%LOGS_DIR%\ZZXRM.tmp"
                    %LOGECHO% Accepting the specified logs directory.
                    %LOGBLANK%
                    goto wroteLogsDone
                :wroteLogsFalse
                    %LOGECHO% The local logs directory is not writable.
                    %LOGBLANK%
                    set LOGS_DIR=
                :wroteLogsDone
            :logsExistsDone

            if NOT "%LOGS_DIR%" == "" goto unsetLogsDone
            :unsetLogsTrue
                set LOGS_DIR=%BACKUP_DIR%
                echo Testing > "%LOGS_DIR%\ZZXRM.tmp"
                if NOT exist "%LOGS_DIR%\ZZXRM.tmp" goto wroteLocalLogsFalse
                :wroteLocalLogsTrue
                    del "%LOGS_DIR%\ZZXRM.tmp"
                    %LOGECHO% Silent Mode: Accepting the backup directory as the logs directory.
                    %LOGBLANK%
                    goto wroteLocalLogsDone
                :wroteLocalLogsFalse
                    %LOGECHO% The backup directory is not writable.
                    %LOGBLANK%
                    set LOGS_DIR=
                :wroteLocalLogsDone
            :unsetLogsDone

            if NOT "%LOGS_DIR%" == "" goto unsetLogsAgainDone
            :unsetLogsAgainTrue
                %LOGECHO% Using the temporary directory as the logs directory.
                %LOGBLANK%
                set LOGS_DIR=%TMP%
                set LEAVELOG=true
            :unsetLogsAgainDone

        goto logsSilentDone

        :logsSilentFalse
            :logsAsYetUnsetTest
            if NOT "%LOGS_DIR%" == "" goto logsAsYetUnsetFalse
                set LOGS_DIR=%BACKUP_DIR%\logs
                if NOT exist "%LOGS_DIR%" goto canUseLocalLogsFalse
                :canUseLocalLogsTrue
                    %LOGECHO% A 'logs' directory is present in the backup directory.
                    echo Testing > "%LOGS_DIR%\ZZXRM.tmp"
                    if NOT exist "%LOGS_DIR%\ZZXRM.tmp" goto canWriteLocalLogsFalse
                    :canWriteLocalLogsTrue
                        del "%LOGS_DIR%\ZZXRM.tmp"
                        %GETINPUT% YORN "Accept 'logs' in the backup directory [y/n]?" "%TMP%\YORN.BAT"
                        call "%TMP%\YORN.BAT"
                        del "%TMP%\YORN.BAT"
                        %LOGBLANK%
                        if NOT "%YORN%" == "yes" goto acceptLocalLogsFalse
                        :acceptLocalLogsTrue
                            %LOGECHO% Accepting 'logs' in the backup directory.
                            %LOGBLANK%
                            goto acceptLocalLogsDone
                        :acceptLocalLogsFalse
                            %LOGECHO% Bypassing 'logs' in the backup directory.
                            %LOGBLANK%
                            set LOGS_DIR=
                        :acceptLocalLogsDone
                        goto canWriteLocalLogsDone
                    :canWriteLocalLogsFalse
                        %LOGECHO% The 'logs' directory under the backup directory is not writable.
                        %LOGBLANK%
                        set LOGS_DIR=
                    :canWriteLocalLogsDone
                    goto canUseLocalLogsDone
                :canUseLocalLogsFalse
                    %LOGECHO% No 'logs' directory is present under the backup directory.
                    %LOGBLANK%
                    set LOGS_DIR=
                :canUseLocalLogsDone
            
                if NOT "%LOGS_DIR%" == "" goto tryBackupLogsDone
                :tryBackupLogsTrue
                    set LOGS_DIR=%BACKUP_DIR%
                    echo Testing > "%LOGS_DIR%\ZZXRM.tmp"
                    if NOT exist "%LOGS_DIR%\ZZXRM.tmp" goto canWriteBackupLogsFalse
                    :canWriteBackupLogsTrue
                        del "%LOGS_DIR%\ZZXRM.tmp"
                        %GETINPUT% YORN "Place logs directly in the backup directory [y/n]?" "%TMP%\YORN.BAT"
                        call "%TMP%\YORN.BAT"
                        del "%TMP%\YORN.BAT"
                        %LOGBLANK%
                        if NOT "%YORN%" == "yes" goto acceptBackupLogsFalse
                        :acceptBackupLogsTrue
                            %LOGECHO% Accepting the backup directory as the logs directory.
                            %LOGBLANK%
                            goto acceptBackupLogsDone
                        :acceptBackupLogsFalse
                            %LOGECHO% Bypassing the backup directory as the logs directory.
                            %LOGBLANK%
                            set LOGS_DIR=
                        :acceptBackupLogsDone
                        goto canWriteBackupLogsDone
                    :canWriteBackupLogsFalse
                        %LOGECHO% The backup directory is not writable.
                        %LOGBLANK%
                        set LOGS_DIR=
                    :canWriteBackupLogsDone
                :tryBackupLogsDone

                if NOT "%LOGS_DIR%" == "" goto tryTmpLogsDone
                :tryTmpLogsTrue
                    set LOGS_DIR=%TMP%
                    %GETINPUT% YORN "Place logs in the temporary directory [y/n]?" "%TMP%\YORN.BAT"
                    call "%TMP%\YORN.BAT"
                    del "%TMP%\YORN.BAT"
                    %LOGBLANK%
                    if NOT "%YORN%" == "yes" goto acceptTmpLogsFalse
                    :acceptTmpLogsTrue
                        %LOGECHO% Logs will be placed in the temporary directory.
                        %LOGBLANK%
                        set LEAVELOG=true
                        goto acceptTmpLogsDone
                    :acceptTmpLogsFalse
                        %LOGECHO% Bypassing the temporary directory.
                        %LOGBLANK%
                        set LOGS_DIR=
                    :acceptTmpLogsDone
                :tryTmpLogsDone

                if NOT "%LOGS_DIR%" == "" goto trySpecifiedLogsDone
                :trySpecifiedLogsTrue
                    %GETINPUT% LOGS_DIR "Specify the directory to use for log files:" "%TMP%\SETLD.BAT"
                    call "%TMP%\SETLD.BAT"
                    del "%TMP%\SETLD.BAT"
                    %LOGBLANK%
                    echo Testing > "%LOGS_DIR%\ZZXRM.tmp"
                    if NOT exist "%LOGS_DIR%\ZZXRM.tmp" goto acceptSpecifiedLogsFalse
                    :acceptSpecifiedLogsTrue
                        del "%LOGS_DIR%\ZZXRM.tmp"
                        %LOGECHO% Accepting the specified logs directory.
                        %LOGBLANK%
                        goto acceptSpecifiedLogsDone
                    :acceptSpecifiedLogsFalse
                        %LOGECHO% The specified logs directory is not writable.
                        %LOGBLANK%
                        set LOGS_DIR=
                    :acceptSpecifiedLogsDone
                :trySpecifiedLogsDone

                if NOT "%LOGS_DIR%" == "" goto haveNoLogsYetDone
                :haveNoLogsYetTrue
                    %GETINPUT% YORN "Cancel this uninstall [y/n]?" "%TMP%\YORN.BAT%"
                    call "%TMP%\YORN.BAT"
                    del "%TMP%\YORN.BAT"
                    %LOGBLANK%
                    if "%YORN%" == "yes" goto quickExit
                :haveNoLogsYetDone
                goto logsAsYetUnsetTest
            :logsAsYetUnsetFalse
        :logsSilentDone
    :logsSetDone
goto afterInitLogs

:initJava 
    %LOGECHO% Locating java runtime

    set JAVA_PATH_EXEC=jre\bin\java.exe

    if "%JAVA_UPDATE_HOME%" == "" goto envJavaFalse
    :envJavaTrue
        %LOGECHO% A java home ['JAVA_UPDATE_HOME'] was set in the environment.

        if NOT exist "%JAVA_UPDATE_HOME%\%JAVA_PATH_EXEC%" acceptEnvJavaFalse
        :acceptEnvJavaTrue
            %LOGECHO% Accepting the environment specified java home ['JAVA_UPDATE_HOME']:
            %LOGECHO% [ %JAVA_UPDATE_HOME% ]
            %LOGBLANK%
            goto acceptEnvJavaDone
        :acceptEnvJavaFalse
            %LOGECHO% The environment specified java home has no java executable:
            %LOGECHO% [ %JAVA_UPDATE_HOME%\%JAVA_PATH_EXEC% ]
            %LOGBLANK%
            goto completedNull
        :acceptEnvJavaDone
        goto envJavaDone

    :envJavaFalse
        %LOGECHO% No java home ['JAVA_UPDATE_HOME'] was set in the environment.

        if NOT "%SILENT%" == "true" goto silentJavaFalse
        :silentJavaTrue
            if NOT exist "%BACKUP_DIR%\java" goto backupJavaExistsFalse
            :backupJavaExistsTrue
                if NOT exist "%BACKUP_DIR%\java\%JAVA_PATH_EXEC%" goto backupJavaOKFalse
                :backupJavaOKTrue
                    %LOGECHO% Java has been located relative to the backup directory.
                    %LOGECHO% [ %BACKUP_DIR%\java ]
                    %LOGBLANK%
                    set JAVA_UPDATE_HOME=%BACKUP_DIR%\java
                    set NOJAVA=false
                    goto backupJavaOKDone
                :backupJavaOKFalse
                    %LOGECHO% No java runtime was found beneath the backup directory:
                    %LOGECHO% [ %BACKUP_DIR%\java\%JAVA_PATH_EXEC% ]
                    %LOGBLANK%
                    set NOJAVA=true
                :backupJavaOKDone
                goto backupJavaExistsDone
            :backupJavaExistsFalse
                %LOGECHO% No java runtime was found beneath the backup directory:
                %LOGECHO% [ %BACKUP_DIR%\java ]
                %LOGBLANK%
                set NOJAVA=true
            :backupJavaExistsDone

            if NOT "%NOJAVA%" == "true" goto noSilentJavaDone
                %LOGECHO% ERROR: Silent Mode: A java runtime could not be located.
                %LOGBLANK%
                goto completedNull
            :noSilentJavaDone
            goto silentJavaDone

        :silentJavaFalse
            :testJavaUnset
            if NOT "%JAVA_UPDATE_HOME%" == "" goto testJavaUnsetDone

                if NOT exist "%BACKUP_DIR%\java\%JAVA_PATH_EXEC%" goto intBackupJavaFalse
                :intBackupJavaTrue
                    %LOGECHO% Java has been located relative to the backup directory.
                    %GETINPUT% YORN "Accept the local java [y/n]?" "%TMP%\YORN.BAT"
                    call "%TMP%\YORN.BAT"
                    del "%TMP%\YORN.BAT"
                    %LOGBLANK%
                    if NOT "%YORN%" == "yes" goto acceptLocalJavaFalse
                    :acceptLocalJavaTrue
                        %LOGECHO% Accepting the local java.
                        set JAVA_UPDATE_HOME=%BACKUP_DIR%\java
                        goto acceptLocalJavaDone
                    :acceptLocalJavaFalse
                        %LOGECHO% Bypassing the local java.
                        set JAVA_UPDATE_HOME=
                    :acceptLocalJavaDone
                    goto intBackupJavaDone
                :intBackupJavaFalse
                    %LOGECHO% Java could not be located relative to the backup directory:
                    %LOGECHO% [ %BACKUP_DIR%\java\%JAVA_PATH_EXEC% ]
                :intBackupJavaDone

                if NOT "%JAVA_UPDATE_HOME%" == "" goto specifyJavaDone
                :specifyJavaTrue
                    %GETINPUT% JAVA_UPDATE_HOME "Specify the java home:" "%TMP%\SETJUH.BAT"
                    call "%TMP%\SETJUH.BAT"
                    del "%TMP%\SETJUH.BAT"
                    if NOT exist "%JAVA_UPDATE_HOME%\%JAVA_PATH_EXEC%" goto acceptJavaFalse
                    :acceptJavaTrue
                        %LOGECHO% Accepting the specified java home.
                        %LOGBLANK%
                        goto acceptJavaDone
                    :acceptJavaFalse
                        %LOGECHO% The specified java home does not contain a java executable:
                        %LOGECHO% [ %JAVA_UPDATE_HOME%\%JAVA_PATH_EXEC% ]
                        %LOGBLANK%
                        set JAVA_UPDATE_HOME=
                    :acceptJavaDone
                :specifyJavaDone

                if NOT "%JAVA_UPDATE_HOME%" == "" goto cancelJavaDone
                :cancelJavaTrue
                    %LOGECHO% A java runtime has not been located.
                    %GETINPUT% YORN "Cancel this uninstall [y/n]?" "%TMP%\YORN.BAT"
                    call "%TMP%\YORN.BAT"
                    del "%TMP%\YORN.BAT"
                    %LOGBLANK%
                    if "%YORN%" == "yes" goto completedNull
                :cancelJavaDone

                goto testJavaUnset
            :testJavaUnsetDone
        :silentJavaDone
    :envJavaDone

    set JAVA_EXEC=%JAVA_UPDATE_HOME%\%JAVA_PATH_EXEC%
    set TMP_JAVA_HOME=%TMP%\java_%PTFNUM%
    set TMP_JAVA_EXEC=%TMP_JAVA_HOME%\%JAVA_PATH_EXEC%
goto afterInitJava

:detectUninstalls 
    %LOGECHO% Searching for backup jar files:
    %LOGBLANK%

    %LOGECHO% Searching for the Application Server backup jar file:
    %LOGBLANK%

    set WAS_BACKUP_JAR=%BACKUP_DIR%/%REL%_ae_%PTFNUM%_backup.jar
    %LOGECHO% Looking for the Advanced Edition backup jar:
    %LOGECHO% [ %WAS_BACKUP_JAR% ]
    %LOGBLANK%

    if NOT exist "%WAS_BACKUP_JAR%" goto foundAEBackupFalse
    :foundAEBackupTrue
        %LOGECHO% An Advanced Edition backup jar was detected.
        %LOGBLANK%
        set WAS_BACKUP_JAR_EXISTS=true
        goto foundAEBackupDone
    :foundAEBackupFalse
        set WAS_BACKUP_JAR=%BACKUP_DIR%/%REL%_aes_%PTFNUM%_backup.jar
        %LOGECHO% Looking for the Advanced Edition, Single Server, backup jar:
        %LOGECHO% [ %WAS_BACKUP_JAR% ].
        %LOGBLANK%
        if NOT exist "%WAS_BACKUP_JAR%" goto foundAEsBackupFalse
        :foundAEsBackupTrue
            %LOGECHO% An Advanced Edition, Single Server backup jar was detected.
            %LOGBLANK%
            set WAS_BACKUP_JAR_EXISTS=true
            goto foundAEsBackupDone
        :foundAEsBackupFalse
            %LOGECHO% No application server backup was detected.
            %LOGBLANK%
            set WAS_BACKUP_JAR=
            set WAS_BACKUP_JAR_EXISTS=false
        :foundAEsBackupDone
    :foundAEBackupDone

    set WAS_LOG_FILE=%LOGS_DIR%\%REL%_%PTFNUM%_uninstall.log

    set JAVA_BACKUP_JAR=%BACKUP_DIR%\jdk_%PTFNUM%_backup.jar
    set JAVA_LOG_FILE=%LOGS_DIR%\jdk_%PTFNUM%_uninstall.log

    set IHS_BACKUP_JAR=%BACKUP_DIR%\ihs_%PTFNUM%_backup.jar
    set IHS_LOG_FILE=%LOGS_DIR%\ihs_%PTFNUM%_uninstall.log

    set J2C_BACKUP_JAR=%BACKUP_DIR%\J2C_%PTFNUM%_backup.jar
    set J2C_LOG_FILE=%LOGS_DIR%\j2c_%PTFNUM%_uninstall.log

    if "%WAS_BACKUP_JAR_EXISTS%" == "false" goto foundWASBackupFalse
    :foundWASBackupTrue
        if NOT "%SKIP_RESTORE_WAS%" == "true" goto setSkipWasFalse
        :setSkipWasTrue
            %LOGECHO% The Application Server restoration was disabled from
            %LOGECHO% the environment ['SKIP_WAS_RESTORE'].
            %LOGBLANK%
            set UPDATEWAS=false
            goto setSkipWasDone
        :setSkipWasFalse
            if NOT "%SILENT%" == "true" goto silentDefaultWasFalse
            :silentDefaultWasTrue
                %LOGECHO% Silent Mode: The Application Server update will be backed out.
                %LOGBLANK%
                set UPDATEWAS=true
                goto silentDefaultWasDone
            :silentDefaultWasFalse
                %GETINPUT% YORN "Back-out the Application Server update [y/n]?" "%TMP%\YORN.BAT"
                call "%TMP%\YORN.BAT"
                del "%TMP%\YORN.BAT"
                %LOGBLANK%
                if NOT "%YORN%" == "yes" goto acceptSkipWasFalse
                :acceptSkipWasTrue
                    %LOGECHO% The Application Server update will be backed out.
                    %LOGBLANK%
                    set UPDATEWAS=true
                    goto acceptSkipWasDone
                :acceptSkipWasFalse
                    %LOGECHO% The Application Server update will not be backed out.
                    %LOGBLANK%
                    set UPDATEWAS=false
                :acceptSkipWasDone
            :silentDefaultWasDone
        :setSkipWasDone
        goto foundWASBackupDone
    :foundWASBackupFalse
        set UPDATEWAS=false
    :foundWASBackupDone

    %LOGECHO% Searching for the JDK backup jar:
    %LOGECHO% [ %JAVA_BACKUP_JAR% ]

    if NOT exist "%JAVA_BACKUP_JAR%" goto foundJAVABackupFalse
    :foundJAVABackupTrue
        %LOGECHO% A JDK backup jar was found.
        %LOGBLANK%

        if NOT "%SKIP_RESTORE_JDK%" == "true" goto setSkipJavaFalse
        :setSkipJavaTrue
            %LOGECHO% The JDK restoration was disabled from the
            %LOGECHO% environment ['SKIP_JDK_RESTORE'].
            %LOGBLANK%
            set UPDATEJDK=false
            goto setSkipJavaDone

        :setSkipJavaFalse
            if NOT "%SILENT%" == "true" goto silentDefaultJavaFalse
            :silentDefaultJavaTrue
                %LOGECHO% Silent Mode: The JDK update will be backed out.
                %LOGBLANK%
                set UPDATEJDK=true
                goto silentDefaultJavaDone

            :silentDefaultJavaFalse
                if NOT "%UPDATEWAS%" == "true" goto showWasUpdateFalse
                :showWasUpdateTrue
                    %LOGECHO% The Application Server update is being backed out.
                    %LOGECHO% The JDK update should also be backed out.
                    goto showWasUpdateDone
                :showWasUpdateFalse
                    %LOGECHO% The Application Server is not being backed out.
                    %LOGECHO% The JDK update should not be backed out.
                :showWasUpdateDone

                %GETINPUT% YORN "Back-out the JDK update [y/n]?" "%TMP%\YORN.BAT"
                call "%TMP%\YORN.BAT"
                del "%TMP%\YORN.BAT"
                %LOGBLANK%
                if NOT "%YORN%" == "yes" goto acceptJavaUpdateFalse
                :acceptJavaUpdateTrue
                    %LOGECHO% The JDK update will be backed out.
                    %LOGBLANK%
                    set UPDATEJDK=true
                    goto acceptJavaUpdateDone
                :acceptJavaUpdateFalse
                    %LOGECHO% The JDK update will not be backed out.
                    %LOGBLANK%
                    set UPDATEJDK=false
                :acceptJavaUpdateDone

            :silentDefaultJavaDone
        :setSkipJavaDone
        goto foundJAVABackupDone
    :foundJAVABackupFalse
        %LOGECHO% No JDK backup jar was found.
        %LOGBLANK%
        set UPDATEJDK=false
    :foundJAVABackupDone

    %LOGECHO% Searching for the IBM HTTP Server backup jar file:
    %LOGECHO% [ %IHS_BACKUP_JAR% ]

    if NOT exist "%IHS_BACKUP_JAR%" goto foundIHSBackupFalse
    :foundIHSBackupTrue
        %LOGECHO% An IBM HTTP Server backup jar was found.
        %LOGBLANK%
        if NOT "%SKIP_RESTORE_IHS%" == "true" goto setSkipIHSFalse
        :setSkipIHSTrue
            %LOGECHO% The IBM HTTP Server restoration was disabled from the
            %LOGECHO% environment ['SKIP_RESTORE_IHS'].
            set UPDATEIHS=false
            goto setSkipIHSDone
        :setSkipIHSFalse
            if NOT "%SILENT%" == "true" goto silentIHSUpdateFalse
            :silentIHSUpdateTrue
                %LOGECHO% Silent Mode: The IBM HTTP Server update will be backed out.
                %LOGBLANK%
                set UPDATEIHS=true
                goto silentIHSUpdateDone
            :silentIHSUpdateFalse
                %GETINPUT% YORN "Back-out the IBM HTTP Server update [y/n]?" "%TMP%\YORN.BAT"
                call "%TMP%\YORN.BAT"
                del "%TMP%\YORN.BAT"
                %LOGBLANK%
                if NOT "%YORN%" == "yes" goto acceptIHSUpdateFalse
                :acceptIHSUpdateTrue
                    %LOGECHO% The IBM HTTP Server update will be backed out.
                    %LOGBLANK%
                    set UPDATEIHS=true
                    goto acceptIHSUpdateDone
                :acceptIHSUpdateFalse
                    %LOGECHO% The IBM HTTP Server update will not be backed out.
                    %LOGBLANK%
                    set UPDATEIHS=false
                :acceptIHSUpdateDone
            :silentIHSUpdateDone
        :setSkipIHSDone
        goto foundIHSBackupDone
    :foundIHSBackupFalse
        %LOGECHO% No IBM HTTP Server backup jar was found.
        %LOGBLANK%
        set UPDATEIHS=false
    :foundIHSBackupDone

    %LOGECHO% Searching for the J2C Connector backup jar file:
    %LOGECHO% [ %J2C_BACKUP_JAR% ]

    if NOT exist "%J2C_BACKUP_JAR%" goto foundJ2CBackupFalse
    :foundJ2CBackupTrue
        %LOGECHO% A J2C Connector backup jar was found.
        %LOGBLANK%
        if NOT "%SKIP_RESTORE_J2C%" == "true" goto setSkipJ2CFalse
        :setSkipJ2CTrue
            %LOGECHO% The J2C Connector restoration was skipped from the
            %LOGECHO% environment ['SKIP_RESTORE_J2C'].
            %LOGBLANK%
            set UPDATEJ2C=false
            goto setSkipJ2CDone
        :setSkipJ2CFalse
            if NOT "%UPDATEWAS%" == "true" goto showWasUpdateJ2CFalse
            :showWasUpdateJ2CTrue
                %LOGECHO% The Application Server update is being backed out.
                %LOGECHO% The J2C Connector update should also be backed out.
                goto showWasUpdateJ2CDone
            :showWasUpdateJ2CFalse
                %LOGECHO% The Application Server is not being backed out.
                %LOGECHO% The J2C Connector update should not be backed out.
            :showWasUpdateJ2CDone

            if NOT "%SILENT%" == "true" goto silentJ2CUpdateFalse
            :silentJ2CUpdateTrue
                if NOT "%UPDATEWAS%" == "true" goto silentDefaultJ2CFalse
                :silentDefaultJ2CTrue
                    %LOGECHO% Silent Mode: The J2C update will be backed out.
                    %LOGBLANK%
                    set UPDATEJ2C=true
                    goto silentDefaultJ2CDone
                :silentDefaultJ2CFalse
                    %LOGECHO% Silent Mode: The J2C update will not be backed out.
                    %LOGBLANK%
                    set UPDATEJ2C=false
                :silentDefaultJ2CDone
                goto silentJ2CUpdateDOne
            :silentJ2CUpdateFalse
                %GETINPUT% YORN "Back-out the J2C Connector update [y/n]?" "%TMP%\YORN.BAT"
                call "%TMP%\YORN.BAT"
                del "%TMP%\YORN.BAT"
                %LOGBLANK%
                if NOT "%YORN%" == "yes" goto acceptJ2CUpdateFalse
                :acceptJ2CUpdateTrue
                    %LOGECHO% The J2C Connector update will be backed out.
                    %LOGBLANK%
                    set UPDATEJ2C=true
                    goto acceptJ2CUpdateDone
                :acceptJ2CUpdateFalse
                    %LOGECHO% The J2C Connector update will not be backed out.
                    %LOGBLANK%
                    set UPDATEJ2C=false
                :acceptJ2CUpdateDone
            :silentJ2CUpdateDone
        :setSkipJ2CDone
        goto foundJ2CBackupDone
    :foundJ2CBackupFalse
        %LOGECHO% No J2C Connector backup jar was found.
        %LOGBLANK%
        set UPDATEJ2C=false
    :foundJ2CBackupDone

    if NOT "%UPDATEWAS%" == "false" goto locatedUpdateTrue
    if NOT "%UPDATEJDK%" == "false" goto locatedUpdateTrue
    if NOT "%UPDATEIHS%" == "false" goto locatedUpdateTrue
    if NOT "%UPDATEJ2C%" == "false" goto locatedUpdateTrue
    goto locatedUpdateFalse

    :locatedUpdateTrue
        %LOGECHO% Completed search for backup jar files:
        %LOGBLANK%

        if NOT "%UPDATEWAS%" == "true" goto wasFalse
        :wasTrue
            %LOGECHO% ==== Application Server:   RESTORE
            goto wasDone
        :wasFalse
            %LOGECHO% ==== Application Server:   NO RESTORE
        :wasDone

        if NOT "%UPDATEJDK%" == "true" goto javaFalse
        :javaTrue
            %LOGECHO% ==== Java Development Kit: RESTORE
            goto javaDone
        :javaFalse
            %LOGECHO% ==== Java Development Kit: NO RESTORE
        :javaDone

        if NOT "%UPDATEIHS%" == "true" goto ihsFalse
        :ihsTrue
            %LOGECHO% ==== IBM HTTP Server:      RESTORE
            goto ihsDone
        :ihsFalse
            %LOGECHO% ==== IBM HTTP Server:      NO RESTORE
        :ihsDone

        if NOT "%UPDATEJ2C%" == "true" goto j2cFalse
        :j2cTrue
            %LOGECHO% ==== J2C Connector:        RESTORE
            %LOGBLANK%
            goto j2cDone
        :j2cFalse
            %LOGECHO% ==== J2C Connector:        NO RESTORE
            %LOGBLANK%
        :j2cDone

        goto locatedUpdateDone
    :locatedUpdateFalse
        %LOGECHO% No uninstalls are scheduled.
        %LOGBLANK%
        goto completedNull
    :locatedUpdateDone
goto afterDetectUninstalls

:performUninstalls 
    if "%SILENT%" == "false" goto pauseDone
    :pauseTrue
    %LOGECHO% Pausing before performing the selected uninstalls.
    pause
    :pauseDone

    goto uninstallJ2C
    :afterUninstallJ2C
    goto uninstallIHS
    :afterUninstallIHS
    goto uninstallJDK
    :afterUninstallJDK
    goto uninstallWAS
    :afterUninstallWAS
goto afterPerformUninstalls

:uninstallJ2C 
    if NOT "%UPDATEJ2C%" == "true" goto doJ2CDone
    :doJ2CTrue
        %LOGECHO% Backing out the J2C update.
        %LOGBLANK%

        set SectionName=backoutJ2C
        set CommandName=backoutJ2C
        set CommandDescription=Back-out the J2C update.
        set CommandLog=Not yet known

        set CMD="%JAVA_EXEC%" -jar "%J2C_BACKUP_JAR%" -log "%J2C_LOG_FILE%" -TmpDir "%TMP%"

        %LOGECHO% Command: %SectionName%: %CommandName%
        %LOGECHO% CommandDescription%
        %LOGECHO% %CMD%
        %LOGBLANK%

        set errorlevel=
        %CMD%
        set localRC=%errorlevel%
        %LOGECHO% returnCode=%localRC%
        %LOGBLANK%

        if NOT (%localRC%) == (0) goto completedJ2CFalse
        :completedJ2CTrue
            %LOGECHO% Completed backing out the J2C update.
            %LOGBLANK%
            set COMPLETEDJ2C="true"
            goto completedJ2CDone
        :completedJ2CFalse
            %LOGECHO% An error occurred while backing out the J2C update.
            goto completedWithError
        :completedJ2CDone

    :doJ2CDone
goto afterUninstallJ2c

:uninstallIHS 
    if NOT "%UPDATEIHS%" == "true" goto doIHSDone
    :doIHSTrue
        %LOGECHO% Backing out the IHS update.
        %LOGBLANK%

        set SectionName=backoutIHS
        set CommandName=backoutIHS
        set CommandDescription=Back-out the IHS update
        set CommandLog=%IHS_LOG_FILE%

        set CMD="%JAVA_EXEC%" -jar "%IHS_BACKUP_JAR%" -log "%IHS_LOG_FILE%" -TmpDir "%TMP%"

        %LOGECHO% Command: %SectionName%: %CommandName%
        %LOGECHO% CommandDescription%
        %LOGECHO% %CMD%
        %LOGBLANK%

        set errorlevel=
        %CMD%
        set localRC=%errorlevel%
        %LOGECHO% returnCode=%localRC%
        %LOGBLANK%

        if NOT (%localRC%) == (0) goto successIHSFalse
        :successIHSTrue
            %LOGECHO% Completed backing out the IHS update.
            %LOGBLANK%
            set COMPLETEDIHS=true
            goto successIHSDone
        :successIHSFalse
            %LOGECHO% An error occurred while backing out the IHS update.
            %LOGBLANK%
            goto completedWithError
        :successIHSDone

    :doIHSDone
goto afterUninstallIHS

:uninstallJDK 
    if NOT "%UPDATEJDK%" == "true" goto doJDKDone
    :goJDKTrue
        %LOGECHO% Backing out the JDK update.
        %LOGBLANK%

        %LOGECHO% Pausing 10 seconds to allow the JDK to settle.
        GetInput Sleep 10 quiet
        %LOGECHO% Completed pause.

        set SectionName=uninstallJDK

        if NOT exist "%TMP_JAVA_HOME%" goto prepareJavaFalse
            set CommandName=prepareTmpJava
            set CommandDescription=Prepare the space for the temporary java.
            set CommandLog=None is available

            %LOGEEVENT% rmdir "%TMP_JAVA_HOME%" /S/Q
            if NOT exist "%TMP_JAVA_HOME"% goto prepareJDKDone
            :prepareJDKFalse
                set localRC=1
                %LOGECHO% An error occurred while preparing space for the temporary java.
                %LOGBLANK%
                goto completedWithError
            :prepareJDKDone
            set localRC=0

        :prepareJavaFalse

        set CommandName=createTmpJava
        set CommandDescription=Create temporary java directory.
        set CommandLog=None is available

        %LOGEVENT% mkdir "%TMP_JAVA_HOME%"
        set localRC=%errorlevel%
        if (%localRC%) == (0) goto createTmpJavaDone
        :createTmpJavaFalse
            %LOGECHO% An error occurred while creating the temporary java directory.
            %LOGBLANK%
            goto completedWithError
        :createTmpJavaDone

        set CommandName=copyTmpJava
        set CommandDescription=Copy the JDK into the temporary directory.
        set CommandLog=None is available

        %LOGEVENT% xcopy "%JAVA_UPDATE_HOME%\*" "%TMP_JAVA_HOME%" /e /q /i
        set localRC=%errorlevel%
        if (%localRC%) == (0) goto copyTmpJavaDone
        :copyTmpJavaFalse
            %LOGECHO% An error occurred while copying the JDK.
            %LOGBLANK%
            goto jdkUpdateError
        :copyTmpJavaDone

        set CommandName=backoutJDKUpdate
        set CommandDescription=Backout the JDK
        set CommandLog=%JAVA_LOG_FILE%

        set CMD="%TMP_JAVA_EXEC%" -jar "%JAVA_BACKUP_JAR%" -log "%JAVA_LOG_FILE%" -TmpDir "%TMP%"

        %LOGECHO% Command: %SectionName%: %CommandName%
        %LOGECHO% CommandDescription%
        %LOGECHO% %CMD%
        %LOGBLANK%

        set errorlevel=
        %CMD%
        set localRC=%errorlevel%
        %LOGECHO% returnCode=%localRC%
        %LOGBLANK%

        if (%localRC%) == (0) goto uninstallJDKDone
        :uninstallJDKError
            %LOGECHO% An error occurred while backing out the JDK update.
            %LOGBLANK%
            goto jdkUpdateError
        :uninstallJDKDone

        %LOGECHO% Pausing 10 seconds to allow the JDK to settle.
        GetInput Sleep 10 quiet
        %LOGECHO% Completed pause.

        set CommandName=removeTmpJava
        set CommandDescription=Remove the temporary JDK.
        set CommandLog=None is available

        %LOGEVENT% rmdir "%TMP_JAVA_HOME%" /S/Q
        if NOT exist "%TMP_JAVA_HOME%" goto removeTmpJavaDone
        :removeTmpJavaError
            set localRC=1
            %LOGECHO% An error occurred while removing the temporary JDK.
            %LOGBLANK%
            goto jdkUpdateError
        :removeTmpJavaDone
        set localRc=0

        %LOGECHO% Completed backing out the JDK update.
        %LOGBLANK%
        set COMPLETEDJDK=true
    :doJDKDone
goto afterUninstallJdK

:jdkUpdateError 
    %LOGECHO% Removing working copy of the JDK.
    %LOGECHO% (An error has already occurred -- complete error
    %LOGECHO% reporting is not available for this operation.)
    %LOGBLANK%
    %LOGECHO% Path to the working copy of the JDK:
    %LOGECHO% %TMP_JAVA_HOME%
    %LOGBLANK%

    echo rmdir "%TMP_JAVA_HOME%" /S/Q

    rmdir "%TMP_JAVA_HOME%" /S/Q
    if exit "%TMP_JAVA_HOME%" goto cleanupJDKFalse
    :cleanupJDKTrue
        set localRC=0
        %LOGECHO% Removed working copy of the JDK.
        %LOGBLANK%
        goto cleanupJDKDone
    :cleanupJDKFalse
        set localRC=1
        %LOGECHO% ERROR: Unable to remove the working copy of the JDK.
        %LOGBLANK%
    :cleanupJDKDone
goto completedWithError

:uninstallWAS 
    if NOT "%UPDATEWAS%" == "true" goto doWasDone
    :doWASTrue
        %LOGECHO% Backing out the Application Server update.
        %LOGBLANK%

        set SectionName=backoutWAS
        set CommandName=backoutWas
        set CommandDescription=Backout the update to the Application Server
        set CommandLog=%WAS_LOG_FILE%

        set CMD="%JAVA_EXEC%" -jar "%WAS_BACKUP_JAR%" -log "%WAS_LOG_FILE%" -TmpDir "%TMP%"

        %LOGECHO% Command: %SectionName%: %CommandName%
        %LOGECHO% CommandDescription%
        %LOGECHO% %CMD%
        %LOGBLANK%

        set errorlevel=
        %CMD%
        set localRC=%errorlevel%
        %LOGECHO% returnCode=%localRC%
        %LOGBLANK%

        if NOT (%localRC%) == (0) goto successWASFalse
        :successWASTrue
           %LOGECHO% Completed backing out the Application Server update.
            %LOGBLANK%
            set COMPLETEDWAS=true
            goto successWASDone
        :successWASFalse
            %LOGECHO% An error occurred while backing out the Application Server update.
            %LOGBLANK%
            goto completedWithError
        :successWASDone

    :doWASDone
goto afterUninstallWAS

:copyLog 
    if NOT "%LEAVELOG%" == "false" goto copyLogDone
    :copyLogTrue
        %LOGECHO% Copying summary log.
        %LOGBLANK%

        set OLD_SUMMARYLOG="%SUMMARYLOG%"
        set NEW_SUMMARYLOG="%LOGS_DIR%\%SUMMARYBASE%"

        set errorLevel=
        %LOGEVENT% copy %OLD_SUMMARYLOG% %NEW_SUMMARYLOG%
        if errorLevel 1 goto didCopyLogFalse
        :didCopyLogTrue
            set SummaryLog=%NEW_SUMMARYLOG%
            %LOGECHO% The summary log was successfully copied.
            goto didCopyLogDone
        :didCopyLogFalse
            %LOGECHO% An error occurred while copying the summary log.
            %LOGBLANK%
        :didCopyLogDone
    :copyLogDone

    %LOGECHO% A file containing the uninstall activity may be found in the summary log file:
    %LOGECHO% %SUMMARYLOG%
    %LOGBLANK%
goto %AFTERCOPYLOG%

:quickExit 
    %LOGECHO% Halting this uninstall.
    %LOGBLANK%
    %LOGECHO% See the log file for details:
    %LOGECHO% %SUMMARYLOG%
    %LOGBLANK%
    %LOGECHO% Result code: 1
    %LOGECHO% The uninstall of WebSphere %PTFNUMSPACED% did not complete successfully.
goto egress

:completedNull 
    %LOGECHO% The update has been halted.

    set AFTERCOPYLOG=logCopyCompletedNull
    goto copyLog
    :logCopyCompletedNull

    %LOGECHO% Result code: 1
    %LOGECHO% The uninstall of WebSphere %PTFNUMSPACED% did not complete successfully.
goto egress

:completedWithError 
    %LOGECHO% Update Error Report:
    %LOGECHO% Section Name: %SectionName%
    %LOGECHO% Command Name: %CommandName%
    %LOGECHO% Command Description: %CommandDescription%
    %LOGECHO% Command Log File: %CommandLog%
    %LOGBLANK%

    if NOT "%UPDATEWAS%" == "true" goto wasErrorFalse
    :wasErrorTrue
        if "%completedWAS%" == "" goto completedWasFalse
        :completedWasTrue
            %LOGECHO% ==== Application Server:   COMPLETE
            goto completedWasDone
        :completedWasFalse
            %LOGECHO% ==== Application Server:   FAILED
        :completedWasDone
        goto wasErrorDone
    :wasErrorFalse
        %LOGECHO% ==== Application Server:   NO RESTORE
    :wasErrorDone

    if NOT "%UPDATEJDK%" == "true" goto javaErrorFalse
    :javaErrorTrue
        if "%completedJDK%" == "" goto completedJavaFalse
        :completedJavaTrue
            %LOGECHO% ==== Java Development Kit: COMPLETE
            goto completedJavaDone
        :completedJavaFalse
            %LOGECHO% ==== Java Development Kit: FAILED
        :completedJavaDone
        goto javaErrorDone
    :javaErrorFalse
        %LOGECHO% ==== Java Development Kit: NO RESTORE
    :javaErrorDone

    if NOT "%UPDATEIHS%" == "true" goto ihsErrorFalse
    :ihsErrorTrue
        if "%completedJDK%" == "" goto completedJDKFalse
        :completedJDKTrue
            %LOGECHO% ==== IBM HTTP Server:      COMPLETE
            goto completedJDKDone
        :completedJDKFalse
            %LOGECHO% ==== IBM HTTP Server:      FAILED
        :completedJDKDone
        goto ihsErrorDone
    :ihsErrorFalse
        %LOGECHO% ==== IBM HTTP Server:      NO RESTORE
    :ihsErrorDone

    if NOT "%UPDATEJ2C%" == "true" goto j2cErrorFalse
    :j2cErrorTrue
        if "%completedJ2C%" == "" goto completedJ2CFalse
        :completedJ2CTrue
            %LOGECHO% ==== J2C Connector:        COMPLETE
            %LOGBLANK%
            goto completedJ2CDone
        :completedJ2CFalse
            %LOGECHO% ==== J2C Connector:        FAILED
            %LOGBLANK%
        :completedJ2CDone
        goto j2cErrorDone
    :j2cErrorFalse
        %LOGECHO% ==== J2C Connector:        NO RESTORE
        %LOGBLANK%
    :j2cErrorDone

    set AFTERCOPYLOG=afterLogCompletedError
    goto copyLog
    :afterLogCompletedError

    %LOGECHO% Result code: 1
    %LOGECHO% The uninstall of WebSphere %PTFNUMSPACED% did not complete successfully.              
goto egress

:complete 
    %LOGECHO% Uninstalled WAS %PTFNUM%

    if NOT "%UPDATEWAS%" == "true" goto wasCompleteFalse
    :wasCompleteTrue
        %LOGECHO% ==== Application Server:   COMPLETE
        goto wasCompleteDone
    :wasCompleteFalse
        %LOGECHO% ==== Application Server:   NO RESTORE
    :wasCompleteDone

    if NOT "%UPDATEJDK%" == "true" goto javaCompleteFalse
    :javaCompleteTrue
        %LOGECHO% ==== Java Development Kit: COMPLETE
        goto javaCompleteDone
    :javaCompleteFalse
        %LOGECHO% ==== Java Development Kit: NO RESTORE
    :javaCompleteDone

    if NOT "%UPDATEIHS%" == "true" goto ihsCompleteFalse
    :ihsCompleteTrue
        %LOGECHO% ==== IBM HTTP Server:      COMPLETE
        goto ihsCompleteDone
    :ihsCompleteFalse
        %LOGECHO% ==== IBM HTTP Server:      NO RESTORE
    :ihsCompleteDone

    if NOT "%UPDATEJ2C%" == "true" goto j2cCompleteFalse
    :j2cCompleteTrue
        %LOGECHO% ==== J2C Connector:        COMPLETE
        %LOGBLANK%
        goto j2cCompleteDone
    :j2cCompleteFalse
        %LOGECHO% ==== J2C Connector:        NO RESTORE
        %LOGBLANK%
    :j2cCompleteDone

    set AFTERCOPYLOG=logCopyComplete
    goto copyLog
    :logCopyComplete
    
    %LOGECHO% NOTE:
    %LOGECHO% Please regenerate the plugin configuration once the server is started in order to update the plugin-cfg.xml file.
    %LOGBLANK%

    %LOGECHO% Result code: 0
    %LOGECHO% The uninstall of WebSphere %PTFNUMSPACED% completed successfully.
goto egress

:egress
rem A pause is required when the install is launched through explorer
rem When launched from the explorer the percent %0 has the full path.

if (%SILENT%) == (true)          Goto finalEgress
if /I (%0)    == (uninstall.bat) Goto finalEgress
if /I (%0)    == (uninstall.bat) Goto finalEgress
pause

:finalEgress
@endLocal
